# Generated by Django 3.0 on 2020-01-16 09:17

import django.contrib.postgres.fields.jsonb
from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='AuditLog',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('object_type', models.CharField(max_length=100)),
                ('object_id', models.BigIntegerField()),
                ('state_delta', models.TextField()),
            ],
        ),
    ]
